from django.apps import AppConfig

class DjangoSSOClientOauthConfig(AppConfig):
    """Django app configuration for django_sso_client_oauth."""
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'django_sso_client_oauth'
